'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

exports.default = function (babel) {
  var t = babel.types,
      template = babel.template;


  return {
    name: "babel-plugin-styled-components-selector", // not required
    visitor: {
      Program: function Program(path, state) {
        // Default imported variable name to "styled", adjust based on import below
        var importedVariableName = 'styled';

        var isStyled = function isStyled(tag) {
          return tag.object && tag.object.name === importedVariableName || tag.callee && tag.callee.name === importedVariableName;
        };

        path.traverse({
          ImportDeclaration: function ImportDeclaration(path) {
            // Is the styled-components import!
            if (path.node.source.value === 'styled-components') {
              // If the default is imported it's at defaultImport[0], otherwise defaultImport is empty
              var defaultImport = path.get('specifiers').find(function (specifier) {
                return specifier.isImportDefaultSpecifier() || specifier.isImportSpecifier() && specifier.node.imported.name === 'default';
              });
              if (defaultImport) {
                // Save the imported name
                importedVariableName = defaultImport.node.local.name;
              }
            }
          }
        });

        path.traverse({
          VariableDeclarator: function VariableDeclarator(path2) {

            path2.traverse({
              TaggedTemplateExpression: function TaggedTemplateExpression(path3) {
                var tag = path3.node.tag;


                if (tag.type === "CallExpression" && tag.callee.name === importedVariableName || tag.type === "MemberExpression" && tag.object.name === importedVariableName) {
                  path2.insertAfter(t.assignmentExpression("=", t.memberExpression(path2.node.id, t.identifier('toString')), t.arrowFunctionExpression([], t.stringLiteral("xx"))));
                }
              }
            });
          }
        });
      }
    }
  };
};